@@ -38,6 +38,8 @@ import job.queue
 import util
 import qutil
 
+if sys.platform.startswith('darwin'):
+    import macosx
 
 _infos = None   # this can hold a list of configured LilyPondInfo instances
 
@@ -159,8 +161,6 @@ class LilyPondInfo(object):
         self.auto = True
         self.name = "LilyPond"
         self._lytools = {}
-        if sys.platform.startswith('darwin'):
-            self.useshebang = False
 
     @property
     def command(self):
@@ -181,7 +181,21 @@ class LilyPondInfo(object):
                 os.path.join('/Applications', 'LilyPond.app', 'Contents', 'Resources', 'bin'),
                 os.path.join('/opt', 'local', 'bin'),
                 os.path.join('/opt', 'lilypond', 'bin'),
+                # Default path for Homebrew on MacOS arm64.
+                '/opt/homebrew/bin',
+                # Default path for Homebrew on MacOS x86_64.
+                '/usr/local/bin',
             ]
+            if macosx.inside_app_bundle():
+                # By default, the PATH environment variable for app bundles
+                # does not contain the path which is required for lilypond
+                # and other helper programs like gs.
+                # Add the lilypond path to PATH to find the helper programs
+                # for Homebrew, Macports and other local installations.
+                exe = util.findexe(self.command, path)
+                if exe:
+                    bindir = os.path.dirname(exe)
+                    os.environ['PATH'] = bindir + ':' + os.environ['PATH']
         else:
             path = None
         return util.findexe(self.command, path) or False
@@ -298,32 +312,10 @@ class LilyPondInfo(object):
             self.datadir = False
         app.job_queue().add_job(j, 'generic')
 
-    @CachedProperty.cachedproperty(depends=(abscommand, bindir))
-    def frommacports(self):
-        """Return True if this LilyPond is provided by MacPorts."""
-        bindir = self.bindir()
-        if sys.platform.startswith('darwin') and bindir:
-            import subprocess
-            portbin = os.path.abspath(self.bindir() + '/port')
-            if os.path.isfile(portbin) and os.access(portbin, os.X_OK):
-                s = subprocess.run([portbin, 'provides', self.abscommand()], capture_output = True)
-                if b'is provided by: lilypond' in s.stdout:
-                    return True
-        return False
-
     def toolcommand(self, original_command, use_ly_tool=True):
         """Return a list containing the commandline to run a tool, e.g. convert-ly.
 
-        On Unix, the list has one element: the full path to the tool.
-
-        On macOS, the list may have up to four elements: the system-provided
-        Python 2 interpreter called in 32 or 64 bit mode (if needed; up to
-        three elements) and the tool path.
-        The 32 bit mode is required for midi2ly in the distributed app
-        bundle of LilyPond <= 2.19.54 and might be in other cases as well.
-        On macOS >= 10.15 Catalina, the system Python cannot be run in 32
-        bit mode, so None is returned.
-        See macosx.best_python and macosx.system_python for more details.
+        On Unix (including macOS), the list has one element: the full path to the tool.
 
         On Windows, the list has two elements: the LilyPond-provided Python
         interpreter and the tool path.
@@ -350,13 +342,6 @@ class LilyPondInfo(object):
             if not os.access(toolpath, os.R_OK) and not toolpath.endswith('.py'):
                 toolpath += '.py'
             command = [self.python(), toolpath]
-        elif sys.platform.startswith('darwin'):
-            import macosx
-            command = macosx.best_python(self, original_command)
-            if command is None:
-                return None
-            else:
-                command.append(toolpath)
         else:
             command = [toolpath]
         return command
@@ -407,8 +392,6 @@ class LilyPondInfo(object):
                     datadir = settings.value("datadir", "", str)
                     if datadir and os.path.isdir(datadir):
                         info.datadir = datadir
-                if sys.platform.startswith('darwin'):
-                    info.useshebang = settings.value("useshebang", False, bool)
                 return info
 
     def write(self, settings):
@@ -426,8 +409,6 @@ class LilyPondInfo(object):
                 settings.remove(name)
             else:
                 settings.setValue(name, value)
-        if sys.platform.startswith('darwin'):
-            settings.setValue("useshebang", self.useshebang)
 
     def python(self):
         """Returns the path to the LilyPond-provided Python interpreter.
